Changelogs
=============

.. toctree::
   :maxdepth: 2

   changelogs/v0.3.0
   changelogs/v1.0.0.post1
   changelogs/v1.0.1
   changelogs/v1.0.2
   changelogs/v1.0.3
   changelogs/v1.0.4
   changelogs/v1.0.5.post1
   changelogs/v1.0.6
   changelogs/v1.0.7
   changelogs/v1.1.0
   changelogs/v1.2.0
